# EDV Data Inspect
A Python Package to analyze the edv data in terms of total edv applicants, the derivatives(family members) and gives only the intended data in the scrap.txt file after running this package.

# Usage
On this https://dvcharts.xarthisius.xyz/ceacFY21.html there is whole lots of data provided for each year edv lottery. The data they provided for year 2020 2021 and so on opens in excel software where we can do analyze.
But if you want to do same for year 2019, 2018, and other previous year, those data doesn't open in excel but they redirect to webpage with that data. So, we can't analyze the exact number that we want to figure out from the data.

Following query will provide you the actual data for total edv winners, total derivatives(family members) for year 2018 and 2019

'''
edv-data-inspect 
'''